The ParameterKind enum exists to provide a single source of truth for how to spell the
parameter value that functions as the header for a given parameter.
The ResultStatus enum represents different possible outcomes for async load and download
tasks.
Used when asynchronous processes need to provide a return value indicating the outcome status
of their task. The primary purpose is for logging and to aid in control flow when managing
tasks.
Represents the scope of retain operations on a Queue. If condition C is the filter for a
subset S of queue Q, then S has Scope::Queue. Let T be the subset of S that is also
contained in the History H, so that Q ⊃ S ⊃ T, where C is true for S, and T ⊂ H. We use
Scope::History to represent the subset T.
Load all successfully downloaded files in the download History for the Dataset.
If the user provides a load_history, the method will exclude previously loaded files in
the provided History.
For each variant of Dataset, request the valid range of values for each parameter name.
BEA has not implemented this method for all parameters, so we expect some calls to fail.
For each variant of Dataset, request the valid range of values for each parameter name.
The subset variant of this method only requests data for datasets where the BEA has
implemented a response for each parameter name associated with the dataset.